[01/10,gdb/ada] Fix argument name misspelling

Message ID 20230602155639.28245-2-tdevries@suse.de
State Committed
Headers
Series Fix typos and misspellings |

Commit Message

Tom de Vries June 2, 2023, 3:56 p.m. UTC
  Two functions use the argument name bounds_prefered_p.

This misspells "preferred".

Fix this by using bounds_preferred_p instead.

Tested on x86_64-linux.
---
 gdb/ada-typeprint.c | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)
  

Patch

diff --git a/gdb/ada-typeprint.c b/gdb/ada-typeprint.c
index 3866b2d35eb..98faf315460 100644
--- a/gdb/ada-typeprint.c
+++ b/gdb/ada-typeprint.c
@@ -122,14 +122,14 @@  type_is_full_subrange_of_target_type (struct type *type)
   return 1;
 }
 
 /* Print TYPE on STREAM, preferably as a range if BOUNDS_PREFERED_P
    is nonzero.  */
 
 static void
 print_range (struct type *type, struct ui_file *stream,
-	     int bounds_prefered_p)
+	     int bounds_preferred_p)
 {
-  if (!bounds_prefered_p)
+  if (!bounds_preferred_p)
     {
       /* Try stripping all TYPE_CODE_RANGE layers whose bounds
 	 are identical to the bounds of their subtype.  When
@@ -253,14 +253,14 @@  print_dynamic_range_bound (struct type *type, const char *name, int name_len,
 /* Print RAW_TYPE as a range type, using any bound information
    following the GNAT encoding (if available).
 
-   If BOUNDS_PREFERED_P is nonzero, force the printing of the range
+   If BOUNDS_PREFERRED_P is nonzero, force the printing of the range
    using its bounds.  Otherwise, try printing the range without
    printing the value of the bounds, if possible (this is only
    considered a hint, not a guaranty).  */
 
 static void
 print_range_type (struct type *raw_type, struct ui_file *stream,
-		  int bounds_prefered_p)
+		  int bounds_preferred_p)
 {
   const char *name;
   struct type *base_type;
@@ -277,7 +277,7 @@  print_range_type (struct type *raw_type, struct ui_file *stream,
 
   subtype_info = strstr (name, "___XD");
   if (subtype_info == NULL)
-    print_range (raw_type, stream, bounds_prefered_p);
+    print_range (raw_type, stream, bounds_preferred_p);
   else
     {
       int prefix_len = subtype_info - name;
@@ -382,7 +382,7 @@  print_array_type (struct type *type, struct ui_file *stream, int show,
 	      if (arr_type != type)
 		gdb_printf (stream, ", ");
 	      print_range (arr_type->index_type (), stream,
-			   0 /* bounds_prefered_p */);
+			   0 /* bounds_preferred_p */);
 	      if (TYPE_FIELD_BITSIZE (arr_type, 0) > 0)
 		bitsize = TYPE_FIELD_BITSIZE (arr_type, 0);
 	      /* A multi-dimensional array is represented using a
@@ -407,7 +407,7 @@  print_array_type (struct type *type, struct ui_file *stream, int show,
 	      if (k > 0)
 		gdb_printf (stream, ", ");
 	      print_range_type (range_desc_type->field (k).type (),
-				stream, 0 /* bounds_prefered_p */);
+				stream, 0 /* bounds_preferred_p */);
 	      if (TYPE_FIELD_BITSIZE (arr_type, 0) > 0)
 		bitsize = TYPE_FIELD_BITSIZE (arr_type, 0);
 	    }
@@ -1031,7 +1031,7 @@  ada_print_type (struct type *type0, const char *varstring,
 	  else
 	    {
 	      gdb_printf (stream, "range ");
-	      print_range_type (type, stream, 1 /* bounds_prefered_p */);
+	      print_range_type (type, stream, 1 /* bounds_preferred_p */);
 	    }
 	}
 	break;
@@ -1048,7 +1048,7 @@  ada_print_type (struct type *type0, const char *varstring,
 	else
 	  {
 	    gdb_printf (stream, "range ");
-	    print_range (type, stream, 1 /* bounds_prefered_p */);
+	    print_range (type, stream, 1 /* bounds_preferred_p */);
 	  }
 	break;
       case TYPE_CODE_FLT:
@@ -122,14 +122,14 @@  type_is_full_subrange_of_target_type (struct type *type)
 }
 
-/* Print TYPE on STREAM, preferably as a range if BOUNDS_PREFERED_P
+/* Print TYPE on STREAM, preferably as a range if BOUNDS_PREFERRED_P
    is nonzero.  */
 